==> sprengnetter-bootstrap-theme-1.0.1.tgz: package/README.md <==
# Sprengnetter Bootstrap 5 Theme

[![npm version](https://badge.fury.io/js/sprengnetter-bootstrap-theme.svg)](https://www.npmjs.com/package/sprengnetter-bootstrap-theme)

## Usage

This theme is a complete replacement for Bootstrap 4. You do not need to include
both, `bootstrap.css` and `sprengnetter-bootstrap-theme.css`. The latter is sufficient.

To use the compiled theme in your webapp, you can either link to our CDN

https://bootstrap.assets.sprengnetter.com/css/X.X.X/sprengnetter-bootstrap-theme.css

(replace x.x.x by your desired version) or copy the contents of a certain
[release](https://github.com/sprengnetter/sprengnetter-bootstrap-theme/releases) to your
designated asset folder or use NPM to install this theme as a dependency.

    npm install sprengnetter-bootstrap-theme --save

If you like to use this theme in your own Sass code and installed this theme
with NPM you can import the source files to your manifest (e.g. `index.scss`)
as well.

```scss
@import "sprengnetter-bootstrap-theme/src/styles/index.scss";
```

## Development

Contribution is always welcome. Please use pull requests, if you want to
incorporate changes or new components. For development purposes of this theme,
we use the official Bootstrap documentation pages and apply the styles of this
theme to it. Therefore this repository uses a submodule to link the official
Bootstrap repository and a build script to generate and serve the documentation
pages locally.

### Setup

- Install node v10 or higher

- Clone project `git clone git@github.com:sprengnetter/sprengnetter-bootstrap-theme.git`
- Go into the project folder `cd sprengnetter-bootstrap-theme`
- Init the Bootstrap submodule `git submodule update --init` (only needed the
  very first time)
- Install Bootstap's documentation pages `npm run docs:install`
- Compile styles and serve documentation `npm start`

Now you should see the Bootstrap documentation pages with sprengnetter styling applied.
`npm start` incorporates a watcher, so you can write code and see your
changes immediately in the browser.

==> sprengnetter-bootstrap-theme-1.0.17.tgz: package/README.md <==
# Sprengnetter Bootstrap 5 Theme

[![npm version](https://badge.fury.io/js/sprengnetter-bootstrap-theme.svg)](https://www.npmjs.com/package/sprengnetter-bootstrap-theme)

## Usage

This theme is a complete replacement for Bootstrap 5. You do not need to include
both, `bootstrap.css` and `sprengnetter-bootstrap-theme.css`. The latter is sufficient.

Copy the contents of a certain
[release](https://github.com/sprengnetter/sprengnetter-bootstrap-theme/releases) to your
designated asset folder or use NPM to install this theme as a dependency.

```bash
  $ npm install sprengnetter-bootstrap-theme --save
```

If you like to use this theme in your own Sass code and installed this theme
with NPM you can import the source files to your manifest (e.g. `index.scss`)
as well.

```scss
@import "sprengnetter-bootstrap-theme/src/styles/index.scss";
```

## Development

Contribution is always welcome. Please use pull requests, if you want to
incorporate changes or new components. For development purposes of this theme,
we use the official Bootstrap documentation pages and apply the styles of this
theme to it. Therefore this repository uses a submodule to link the official
Bootstrap repository and a build script to generate and serve the documentation
pages locally.

### Setup

- Install node v10 or higher

- Clone project `git clone git@github.com:sprengnetter/sprengnetter-bootstrap-theme.git`
- Go into the project folder `cd sprengnetter-bootstrap-theme`
- Init the Bootstrap submodule `git submodule update --init` (only needed the
  very first time)
- Install Bootstap's documentation pages `npm run docs:install`
- Compile styles and serve documentation `npm start`

Now you should see the Bootstrap documentation pages with sprengnetter styling applied.
`npm start` incorporates a watcher, so you can write code and see your
changes immediately in the browser.
